==> jc-1.4.0.tar.gz: soot/jimple/toolkits/scalar/pre/LazyCodeMotion__242.h <==
// class soot.jimple.toolkits.scalar.pre.LazyCodeMotion$2

// class file dependencies
// @dep_class 2a7152deee1944f1 java_lang_Object
// @dep_class a46ccd6075e54e4d soot_jimple_toolkits_scalar_pre_LazyCodeMotion__242
// @dep_class 579f594fd302330c soot_util_UnitMap

// header file dependencies
// @dep_header soot_util_UnitMap

#include "soot/util/UnitMap.h"

#ifndef _JC_soot_jimple_toolkits_scalar_pre_LazyCodeMotion__242_H_
#define _JC_soot_jimple_toolkits_scalar_pre_LazyCodeMotion__242_H_

// Forward structure declarations
struct _jc_java_lang_Class$object;
struct _jc_java_lang_Object$object;
struct _jc_soot_Body$object;
struct _jc_soot_Unit$object;
struct _jc_soot_jimple_toolkits_scalar_pre_LazyCodeMotion$object;

// Typedefs
typedef struct _jc_soot_jimple_toolkits_scalar_pre_LazyCodeMotion__242$sub_refs	_jc_soot_jimple_toolkits_scalar_pre_LazyCodeMotion__242$sub_refs;
typedef struct _jc_soot_jimple_toolkits_scalar_pre_LazyCodeMotion__242$sub_nonrefs	_jc_soot_jimple_toolkits_scalar_pre_LazyCodeMotion__242$sub_nonrefs;
typedef struct _jc_soot_jimple_toolkits_scalar_pre_LazyCodeMotion__242$refs	_jc_soot_jimple_toolkits_scalar_pre_LazyCodeMotion__242$refs;
typedef struct _jc_soot_jimple_toolkits_scalar_pre_LazyCodeMotion__242$nonrefs	_jc_soot_jimple_toolkits_scalar_pre_LazyCodeMotion__242$nonrefs;
typedef struct _jc_soot_jimple_toolkits_scalar_pre_LazyCodeMotion__242$object	_jc_soot_jimple_toolkits_scalar_pre_LazyCodeMotion__242$object;

typedef const struct _jc_soot_jimple_toolkits_scalar_pre_LazyCodeMotion__242$vmethods	_jc_soot_jimple_toolkits_scalar_pre_LazyCodeMotion__242$vmethods;
typedef const struct _jc_soot_jimple_toolkits_scalar_pre_LazyCodeMotion__242$vtable	_jc_soot_jimple_toolkits_scalar_pre_LazyCodeMotion__242$vtable;
typedef const struct _jc_soot_jimple_toolkits_scalar_pre_LazyCodeMotion__242$vtype	_jc_soot_jimple_toolkits_scalar_pre_LazyCodeMotion__242$vtype;

// Constructors
extern void _jc_soot_jimple_toolkits_scalar_pre_LazyCodeMotion__242$method$_init$19b1ee072615d433(_jc_env *, struct _jc_soot_jimple_toolkits_scalar_pre_LazyCodeMotion__242$object *, struct _jc_soot_jimple_toolkits_scalar_pre_LazyCodeMotion$object *, struct _jc_soot_Body$object *, jint, jfloat);

// Virtual methods
extern struct _jc_java_lang_Object$object *_jc_soot_jimple_toolkits_scalar_pre_LazyCodeMotion__242$method$mapTo$0732bdedb610eb76(_jc_env *, struct _jc_soot_jimple_toolkits_scalar_pre_LazyCodeMotion__242$object *, struct _jc_object *);

// Virtual method descriptors
extern _jc_method _jc_soot_jimple_toolkits_scalar_pre_LazyCodeMotion__242$method_info$mapTo$0732bdedb610eb76;

// Virtual methods structure
struct _jc_soot_jimple_toolkits_scalar_pre_LazyCodeMotion__242$vmethods {
	struct _jc_java_lang_Object$object	*(*mapTo$0732bdedb610eb76)(_jc_env *, struct _jc_soot_jimple_toolkits_scalar_pre_LazyCodeMotion__242$object *, struct _jc_object *);
};

// Vtable
struct _jc_soot_jimple_toolkits_scalar_pre_LazyCodeMotion__242$vtable {
	_jc_java_lang_Object$vmethods	java_lang_Object;
	_jc_soot_util_UnitMap$vmethods	soot_util_UnitMap;
	_jc_soot_jimple_toolkits_scalar_pre_LazyCodeMotion__242$vmethods	soot_jimple_toolkits_scalar_pre_LazyCodeMotion__242;
};

// Vtype
struct _jc_soot_jimple_toolkits_scalar_pre_LazyCodeMotion__242$vtype {
	_jc_type			type;
	_jc_soot_jimple_toolkits_scalar_pre_LazyCodeMotion__242$vtable	vtable;
};

// Reference instance fields (subclass)
struct _jc_soot_jimple_toolkits_scalar_pre_LazyCodeMotion__242$sub_refs {
	struct _jc_soot_jimple_toolkits_scalar_pre_LazyCodeMotion$object	*this__240;
};

// Reference instance fields (object)
struct _jc_soot_jimple_toolkits_scalar_pre_LazyCodeMotion__242$refs {
    _jc_soot_jimple_toolkits_scalar_pre_LazyCodeMotion__242$sub_refs	soot_jimple_toolkits_scalar_pre_LazyCodeMotion__242;
    _jc_soot_util_UnitMap$sub_refs	soot_util_UnitMap;
    _jc_java_lang_Object$sub_refs	java_lang_Object;
};

// Non-reference instance fields (subclass)
struct _jc_soot_jimple_toolkits_scalar_pre_LazyCodeMotion__242$sub_nonrefs {
};

// Non-reference instance fields (object)
struct _jc_soot_jimple_toolkits_scalar_pre_LazyCodeMotion__242$nonrefs {
    _jc_java_lang_Object$sub_nonrefs	java_lang_Object;
    _jc_soot_util_UnitMap$sub_nonrefs	soot_util_UnitMap;
    _jc_soot_jimple_toolkits_scalar_pre_LazyCodeMotion__242$sub_nonrefs	soot_jimple_toolkits_scalar_pre_LazyCodeMotion__242;
};

// Object instance structure
struct _jc_soot_jimple_toolkits_scalar_pre_LazyCodeMotion__242$object {
	_jc_soot_jimple_toolkits_scalar_pre_LazyCodeMotion__242$refs	refs[0];
	_jc_word		lockword;
	_jc_soot_jimple_toolkits_scalar_pre_LazyCodeMotion__242$vtype	*vtype;
	_jc_soot_jimple_toolkits_scalar_pre_LazyCodeMotion__242$nonrefs	nonrefs;
};

// Type structure
extern _jc_soot_jimple_toolkits_scalar_pre_LazyCodeMotion__242$vtype _jc_soot_jimple_toolkits_scalar_pre_LazyCodeMotion__242$type;

// Array types class info structures
_JC_DECL_ARRAYS(soot_jimple_toolkits_scalar_pre_LazyCodeMotion__242, type);

// java.lang.Class instance
extern struct _jc_java_lang_Class$object _jc_soot_jimple_toolkits_scalar_pre_LazyCodeMotion__242$class_object;

#endif	/* _JC_soot_jimple_toolkits_scalar_pre_LazyCodeMotion__242_H_ */

==> jc-1.4.6.tar.gz: soot/jimple/toolkits/scalar/pre/LazyCodeMotion__242.h <==
// class soot.jimple.toolkits.scalar.pre.LazyCodeMotion$2

// class file dependencies
// @dep_class 1c4f1fc002fc96e5 java_lang_Object
// @dep_class a46ccd6075e54e4d soot_jimple_toolkits_scalar_pre_LazyCodeMotion__242
// @dep_class 579f594fd302330c soot_util_UnitMap

// header file dependencies
// @dep_header soot_util_UnitMap

#include "soot/util/UnitMap.h"

#ifndef _JC_soot_jimple_toolkits_scalar_pre_LazyCodeMotion__242_H_
#define _JC_soot_jimple_toolkits_scalar_pre_LazyCodeMotion__242_H_

// Forward structure declarations
struct _jc_java_lang_Class$object;
struct _jc_java_lang_Object$object;
struct _jc_soot_Body$object;
struct _jc_soot_Unit$object;
struct _jc_soot_jimple_toolkits_scalar_pre_LazyCodeMotion$object;

// Typedefs
typedef struct _jc_soot_jimple_toolkits_scalar_pre_LazyCodeMotion__242$sub_refs	_jc_soot_jimple_toolkits_scalar_pre_LazyCodeMotion__242$sub_refs;
typedef struct _jc_soot_jimple_toolkits_scalar_pre_LazyCodeMotion__242$sub_nonrefs	_jc_soot_jimple_toolkits_scalar_pre_LazyCodeMotion__242$sub_nonrefs;
typedef struct _jc_soot_jimple_toolkits_scalar_pre_LazyCodeMotion__242$refs	_jc_soot_jimple_toolkits_scalar_pre_LazyCodeMotion__242$refs;
typedef struct _jc_soot_jimple_toolkits_scalar_pre_LazyCodeMotion__242$nonrefs	_jc_soot_jimple_toolkits_scalar_pre_LazyCodeMotion__242$nonrefs;
typedef struct _jc_soot_jimple_toolkits_scalar_pre_LazyCodeMotion__242$object	_jc_soot_jimple_toolkits_scalar_pre_LazyCodeMotion__242$object;

typedef const struct _jc_soot_jimple_toolkits_scalar_pre_LazyCodeMotion__242$vmethods	_jc_soot_jimple_toolkits_scalar_pre_LazyCodeMotion__242$vmethods;
typedef const struct _jc_soot_jimple_toolkits_scalar_pre_LazyCodeMotion__242$vtable	_jc_soot_jimple_toolkits_scalar_pre_LazyCodeMotion__242$vtable;
typedef const struct _jc_soot_jimple_toolkits_scalar_pre_LazyCodeMotion__242$vtype	_jc_soot_jimple_toolkits_scalar_pre_LazyCodeMotion__242$vtype;

// Constructors
extern void _jc_soot_jimple_toolkits_scalar_pre_LazyCodeMotion__242$method$_init$19b1ee072615d433(_jc_env *, struct _jc_soot_jimple_toolkits_scalar_pre_LazyCodeMotion__242$object *, struct _jc_soot_jimple_toolkits_scalar_pre_LazyCodeMotion$object *, struct _jc_soot_Body$object *, jint, jfloat) _JC_JCNI_ATTR;

// Virtual methods
extern struct _jc_java_lang_Object$object *_jc_soot_jimple_toolkits_scalar_pre_LazyCodeMotion__242$method$mapTo$0732bdedb610eb76(_jc_env *, struct _jc_soot_jimple_toolkits_scalar_pre_LazyCodeMotion__242$object *, struct _jc_object *) _JC_JCNI_ATTR;

// Virtual method descriptors
extern _jc_method _jc_soot_jimple_toolkits_scalar_pre_LazyCodeMotion__242$method_info$mapTo$0732bdedb610eb76;

// Virtual methods structure
struct _jc_soot_jimple_toolkits_scalar_pre_LazyCodeMotion__242$vmethods {
	struct _jc_java_lang_Object$object	*(*mapTo$0732bdedb610eb76)(_jc_env *, struct _jc_soot_jimple_toolkits_scalar_pre_LazyCodeMotion__242$object *, struct _jc_object *) _JC_JCNI_ATTR;
};

// Vtable
struct _jc_soot_jimple_toolkits_scalar_pre_LazyCodeMotion__242$vtable {
	_jc_java_lang_Object$vmethods	java_lang_Object;
	_jc_soot_util_UnitMap$vmethods	soot_util_UnitMap;
	_jc_soot_jimple_toolkits_scalar_pre_LazyCodeMotion__242$vmethods	soot_jimple_toolkits_scalar_pre_LazyCodeMotion__242;
};

// Vtype
struct _jc_soot_jimple_toolkits_scalar_pre_LazyCodeMotion__242$vtype {
	_jc_type			type;
	_jc_soot_jimple_toolkits_scalar_pre_LazyCodeMotion__242$vtable	vtable;
};

// Reference instance fields (subclass)
struct _jc_soot_jimple_toolkits_scalar_pre_LazyCodeMotion__242$sub_refs {
	struct _jc_soot_jimple_toolkits_scalar_pre_LazyCodeMotion$object	*this__240;
};

// Reference instance fields (object)
struct _jc_soot_jimple_toolkits_scalar_pre_LazyCodeMotion__242$refs {
    _jc_soot_jimple_toolkits_scalar_pre_LazyCodeMotion__242$sub_refs	soot_jimple_toolkits_scalar_pre_LazyCodeMotion__242;
    _jc_soot_util_UnitMap$sub_refs	soot_util_UnitMap;
    _jc_java_lang_Object$sub_refs	java_lang_Object;
};

// Non-reference instance fields (subclass)
struct _jc_soot_jimple_toolkits_scalar_pre_LazyCodeMotion__242$sub_nonrefs {
};

// Non-reference instance fields (object)
struct _jc_soot_jimple_toolkits_scalar_pre_LazyCodeMotion__242$nonrefs {
    _jc_java_lang_Object$sub_nonrefs	java_lang_Object;
    _jc_soot_util_UnitMap$sub_nonrefs	soot_util_UnitMap;
    _jc_soot_jimple_toolkits_scalar_pre_LazyCodeMotion__242$sub_nonrefs	soot_jimple_toolkits_scalar_pre_LazyCodeMotion__242;
};

// Object instance structure
struct _jc_soot_jimple_toolkits_scalar_pre_LazyCodeMotion__242$object {
	_jc_soot_jimple_toolkits_scalar_pre_LazyCodeMotion__242$refs	refs[0];
	_jc_word		lockword;
	_jc_soot_jimple_toolkits_scalar_pre_LazyCodeMotion__242$vtype	*vtype;
	_jc_soot_jimple_toolkits_scalar_pre_LazyCodeMotion__242$nonrefs	nonrefs;
};

// Type structure
extern _jc_soot_jimple_toolkits_scalar_pre_LazyCodeMotion__242$vtype _jc_soot_jimple_toolkits_scalar_pre_LazyCodeMotion__242$type;

// Array types class info structures
_JC_DECL_ARRAYS(soot_jimple_toolkits_scalar_pre_LazyCodeMotion__242, type);

// java.lang.Class instance
extern struct _jc_java_lang_Class$object _jc_soot_jimple_toolkits_scalar_pre_LazyCodeMotion__242$class_object;

#endif	/* _JC_soot_jimple_toolkits_scalar_pre_LazyCodeMotion__242_H_ */
